matrix or data.frame containing coordinates to serve as
a reference for the center of the projection. Columns must be:
"longitude" and "latitude", in that order.
spatial_object
Spatial* objects, Points or Polygons, to be used to
calculate a reference for the center of the projection. Projection must be
WGS84 (EPSG:4326).
Value
An object of class CRS.
Details
If arguments are not defined projection is centered in 0, 0 for
longitude and latitude.